@@ -1,7 +1,7 @@
 package Complete::Getopt::Long;
 
-our $DATE = '2014-12-28'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2014-12-29'; # DATE
+our $VERSION = '0.26'; # VERSION
 
 use 5.010001;
 use strict;
@@ -169,7 +169,7 @@ keys:
   that means this is the first time this option has been seen; undef when
   type='arg')
 * `seen_opts` (hash, all the options seen in `words`)
-* `parsed_opts` (hash, options parsed the standard way)
+* `parsed_opts` (hash, options parsed the standard/raw way)
 
 as well as all keys from `extras` (but these won't override the above keys).
 
@@ -324,14 +324,14 @@ sub complete_cli_arg {
         if ($word =~ /\A-/) {
 
             # split bundled short options
-          SPLIT:
+          SPLIT_BUNDLED:
             {
                 my $shorts = $word;
                 if ($shorts =~ s/\A-([^-])(.*)/$2/) {
                     my $opt = "-$1";
                     my $opthash = $opts{$opt};
                     if (!$opthash || $opthash->{parsed}{max_vals}) {
-                        last SPLIT;
+                        last SPLIT_BUNDLED;
                     }
                     $words[$i] = $word = "-$1";
                     $expects[$i]{prefix} = $word;
@@ -367,6 +367,15 @@ sub complete_cli_arg {
                 }
             }
 
+            # split --foo=val -> --foo, =, val
+          SPLIT_EQUAL:
+            {
+                if ($word =~ /\A(--[^=]+)(=)(.*)/) {
+                    splice @words, $i, 1, $1, $2, $3;
+                    $word = $1;
+                }
+            }
+
             my $opt = $word;
             my $opthash = _expand1($opt, \%opts);
 
@@ -414,7 +423,6 @@ sub complete_cli_arg {
                     $expects[$i] = {separator=>1, optval=>undef, word=>''};
                     if ($i+1 < @words) {
                         $i++;
-                        push @{ $parsed_opts{$opt} }, $words[$i];
                         $expects[$i]{optval} = $opt;
                     }
                 }
@@ -430,6 +438,7 @@ sub complete_cli_arg {
     #say "D:cword: $cword";
     #use DD; print "D:expects: "; dd \@expects;
     #use DD; print "D:seen_opts: "; dd \%seen_opts;
+    #use DD; print "D:parsed_opts: "; dd \%parsed_opts;
 
     my $exp = $expects[$cword];
     my $word = $exp->{word} // $words[$cword];
@@ -493,6 +502,7 @@ sub complete_cli_arg {
             type=>'optval', words=>$args{words}, cword=>$args{cword},
             word=>$word, opt=>$opt, ospec=>$opthash->{ospec},
             argpos=>undef, nth=>$exp->{nth}, seen_opts=>\%seen_opts,
+            parsed_opts=>\%parsed_opts,
         );
         my $compres;
         if ($comp) {
@@ -566,7 +576,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.25 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2014-12-28.
+This document describes version 0.26 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2015-12-29.
 
 =head1 SYNOPSIS
 
@@ -627,7 +637,7 @@ type='arg')
 
 =item * C<seen_opts> (hash, all the options seen in C<words>)
 
-=item * C<parsed_opts> (hash, options parsed the standard way)
+=item * C<parsed_opts> (hash, options parsed the standard/raw way)
 
 =back
 
